@@ -43,6 +43,7 @@ EnvironmentVariables = {
     'config_file': (None, 'AWS_CONFIG_FILE', None),
     'access_key': ('aws_access_key_id', 'AWS_ACCESS_KEY_ID', None),
     'secret_key': ('aws_secret_access_key', 'AWS_SECRET_ACCESS_KEY', None),
+    'token': ('aws_security_token', 'AWS_SECURITY_TOKEN', None),
     'provider': ('provider', 'BOTO_PROVIDER_NAME', 'aws')
     }
 """
@@ -62,6 +63,7 @@ The default set of logical variable names are:
 * config_file - Location of a Boto config file.
 * access_key - The AWS access key part of your credentials.
 * secret_key - The AWS secret key part of your credentials.
+* token - The security token part of your credentials (session tokens only)
 * provider - The name of the service provider (e.g. aws)
 
 These form the keys of the dictionary.  The values in the dictionary
